@@ -1,7 +1,7 @@
 package org.tanukisoftware.wrapper;
 
 /*
- * Copyright (c) 1999, 2010 Tanuki Software, Ltd.
+ * Copyright (c) 1999, 2017 Tanuki Software, Ltd.
  * http://www.tanukisoftware.com
  * All rights reserved.
  *
@@ -13,8 +13,6 @@ package org.tanukisoftware.wrapper;
 
 import java.io.IOException;
 import java.io.InterruptedIOException;
-import java.lang.reflect.InvocationTargetException;
-import java.lang.reflect.Method;
 import java.net.InetAddress;
 import java.net.Socket;
 import java.net.SocketException;
@@ -44,6 +42,7 @@ import org.tanukisoftware.wrapper.WrapperManager;
  *   <li><b>V</b> : Cause an access violation. (For testing)</li>
  *   <li><b>G</b> : Make the JVM appear to be hung. (For testing)</li>
  * </ul>
+ * <p>
  * Additional user defined actions can be defined by calling the
  *  {@link #registerAction( byte command, Runnable action )} method.
  *  The Wrapper project reserves the right to define any upper case
@@ -209,14 +208,17 @@ public class WrapperActionServer
                     //  when the compiler gives an error saying that it can't.
                     if ( m_runnerStop
                         && ( ( t instanceof InterruptedException )
-                        || ( t instanceof SocketException )
-                        || ( t instanceof InterruptedIOException ) ) )
+                            || ( t instanceof SocketException )
+                            || ( t instanceof InterruptedIOException )
+                            || ( ( t instanceof IOException ) && ( t.getMessage() != null ) && ( t.getMessage().indexOf( "Bad file descriptor" ) >= 0 ) )  // Happens on shutdown on IA64 Linux.
+                            )
+                        )
                     {
                         // This is expected, the service is being stopped.
                     }
                     else
                     {
-                        m_out.println( WrapperManager.getRes().getString( "Unexpeced error." ) );
+                        m_out.println( WrapperManager.getRes().getString( "Unexpected error." ) );
                         t.printStackTrace( m_out );
                         
                         // Avoid tight thrashing
@@ -447,38 +449,7 @@ public class WrapperActionServer
                 {
                     public void run()
                     {
-                        // Execute runtime.halt(0) using reflection so this class will
-                        //  compile on 1.2.x versions of Java.
-                        Method haltMethod;
-                        try
-                        {
-                            haltMethod =
-                                Runtime.class.getMethod( "halt", new Class[] { Integer.TYPE } );
-                        }
-                        catch ( NoSuchMethodException e )
-                        {
-                            m_out.println( WrapperManager.getRes().getString( "halt not supported by current JVM." ) );
-                            haltMethod = null;
-                        }
-                        
-                        if ( haltMethod != null )
-                        {
-                            Runtime runtime = Runtime.getRuntime();
-                            try
-                            {
-                                haltMethod.invoke( runtime, new Object[] { new Integer( 0 ) } );
-                            }
-                            catch ( IllegalAccessException e )
-                            {
-                                m_out.println( WrapperManager.getRes().getString(
-                                    "Unable to call runitme.halt: {0}", e.getMessage() ) );
-                            }
-                            catch ( InvocationTargetException e )
-                            {
-                                m_out.println( WrapperManager.getRes().getString( 
-                                    "Unable to call runitme.halt: {0}", e.getMessage() ) );
-                            }
-                        }
+                        Runtime.getRuntime().halt( 0 );
                     }
                 } );
         }
